//
//  Semester.swift
//  TeachMate
//
//  Created by Hongli on 2025/3/12.
//

import Foundation
import SwiftData

@Model
final class Semester {
    var title: String
    var startDate: Date
    var endDate: Date
    var weeksCount: Int
    var isCurrent: Bool = false
    var createdAt: Date = Date()
    
    init(title: String, startDate: Date, endDate: Date, weeksCount: Int, isCurrent: Bool = false) {
        self.title = title
        self.startDate = startDate
        self.endDate = endDate
        self.weeksCount = weeksCount
        self.isCurrent = isCurrent
        self.createdAt = Date()
    }
    
    // Helper method to create a semester with a standard format title
    static func create(startYear: Int, endYear: Int, semesterNumber: Int, startDate: Date, endDate: Date, weeksCount: Int) -> Semester {
        let title = "\(startYear)-\(endYear)-\(semesterNumber)"
        return Semester(title: title, startDate: startDate, endDate: endDate, weeksCount: weeksCount)
    }
    
    // Helper to get current academic week number
    func currentWeekNumber(from date: Date = Date()) -> Int? {
        guard date >= startDate && date <= endDate else { return nil }
        
        let calendar = Calendar.current
        let components = calendar.dateComponents([.day], from: startDate, to: date)
        guard let days = components.day else { return nil }
        
        let weekNumber = (days / 7) + 1
        return weekNumber <= weeksCount ? weekNumber : nil
    }
}
